Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(568)

Unified Diff: ppapi/c/ppb_message_loop.h

Issue 11364188: PPAPI: Take PPB_MessageLoop out of Dev (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: merge Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/c/dev/ppb_message_loop_dev.h ('k') | ppapi/cpp/dev/message_loop_dev.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/c/ppb_message_loop.h
diff --git a/ppapi/c/dev/ppb_message_loop_dev.h b/ppapi/c/ppb_message_loop.h
similarity index 96%
rename from ppapi/c/dev/ppb_message_loop_dev.h
rename to ppapi/c/ppb_message_loop.h
index 5f419743d95b3bb5e824d4950fd5c1c8a6b83b1e..331360bc3dfc1e276b30c09ca2adb3305e0a8960 100644
--- a/ppapi/c/dev/ppb_message_loop_dev.h
+++ b/ppapi/c/ppb_message_loop.h
@@ -3,10 +3,10 @@
* found in the LICENSE file.
*/
-/* From dev/ppb_message_loop_dev.idl modified Wed Aug 29 12:22:26 2012. */
+/* From ppb_message_loop.idl modified Mon Nov 12 13:33:16 2012. */
-#ifndef PPAPI_C_DEV_PPB_MESSAGE_LOOP_DEV_H_
-#define PPAPI_C_DEV_PPB_MESSAGE_LOOP_DEV_H_
+#ifndef PPAPI_C_PPB_MESSAGE_LOOP_H_
+#define PPAPI_C_PPB_MESSAGE_LOOP_H_
#include "ppapi/c/pp_bool.h"
#include "ppapi/c/pp_completion_callback.h"
@@ -15,12 +15,12 @@
#include "ppapi/c/pp_resource.h"
#include "ppapi/c/pp_stdint.h"
-#define PPB_MESSAGELOOP_DEV_INTERFACE_0_1 "PPB_MessageLoop(Dev);0.1"
-#define PPB_MESSAGELOOP_DEV_INTERFACE PPB_MESSAGELOOP_DEV_INTERFACE_0_1
+#define PPB_MESSAGELOOP_INTERFACE_1_0 "PPB_MessageLoop;1.0"
+#define PPB_MESSAGELOOP_INTERFACE PPB_MESSAGELOOP_INTERFACE_1_0
/**
* @file
* Defines the PPB_MessageLoop_Dev interface.
*/
@@ -142,7 +142,7 @@
* implementation of your callback checks the "result" argument and returns
* immediately on error.
*/
-struct PPB_MessageLoop_Dev_0_1 {
+struct PPB_MessageLoop_1_0 {
/**
* Creates a message loop resource.
*
@@ -260,7 +260,8 @@ struct PPB_MessageLoop_Dev_0_1 {
* before that point will be processed before quitting.
*
* This may be called on the message loop registered for the current thread,
- * or it may be called on the message loop registered for another thread.
+ * or it may be called on the message loop registered for another thread. It
+ * is an error to attempt to PostQuit() the main thread loop.
*
* @param should_destroy Marks the message loop as being in a destroyed state
* and prevents further posting of messages.
@@ -279,10 +280,10 @@ struct PPB_MessageLoop_Dev_0_1 {
int32_t (*PostQuit)(PP_Resource message_loop, PP_Bool should_destroy);
};
-typedef struct PPB_MessageLoop_Dev_0_1 PPB_MessageLoop_Dev;
+typedef struct PPB_MessageLoop_1_0 PPB_MessageLoop;
/**
* @}
*/
-#endif /* PPAPI_C_DEV_PPB_MESSAGE_LOOP_DEV_H_ */
+#endif /* PPAPI_C_PPB_MESSAGE_LOOP_H_ */
« no previous file with comments | « ppapi/c/dev/ppb_message_loop_dev.h ('k') | ppapi/cpp/dev/message_loop_dev.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -15,12 +15,12 @@
/**
* @file
- * Defines the PPB_MessageLoop_Dev interface.
+ * Defines the PPB_MessageLoop interface.
*/
This is Rietveld 408576698